import os
import string
import time
import zipfile

zipInfoFilename = "zipInfoBasePath.txt"


# UTILITY

def rmdirRecurse( path ):
	if os.path.isdir(path):
		names = os.listdir(path)
		for name in names:
			fullName = os.path.join(path, name)
			if os.path.isdir(fullName):
				rmdirRecurse(fullName)
			else:
				os.remove(fullName)
		os.rmdir(path)
	else:
		os.remove(path)
	return


def mkdirRecurse( fullpath ):
	(drive, path) = os.path.splitdrive(fullpath)
	if path[:1] == "\\":
		path = path[1:]
	if path[-1:] == "\\":
		path = path[:-1]
	subpaths = string.split(path, "\\")
	currentPath = drive
	for sub in subpaths[0:]:
		currentPath = currentPath + "\\" + sub
		if not os.path.exists(currentPath):
			os.mkdir(currentPath)
	return


# ZIP UP

def zipRecurse( path, archive ):
	names = os.listdir(path)
	for name in names:
		fullName = os.path.join(path, name)
		if os.path.isdir(fullName):
			zipRecurse(fullName, archive)
		else:
			archive.write(fullName)
	return

def zip( sourcePaths, zipFileName, overwrite = 0, basePath = "" ):
	zipFileName = os.path.normpath(zipFileName)

	if os.path.exists(zipFileName) and not overwrite:
		return (0,)

	global zipInfoFilename
	
	zipFile = zipfile.ZipFile(zipFileName, "w", zipfile.ZIP_DEFLATED)
	# add the directory we are zipping from
	if basePath != "":
		currentUTC = time.gmtime(time.time())
		zipInfo = zipfile.ZipInfo(zipInfoFilename, currentUTC[:6])
		zipFile.writestr(zipInfo, os.path.normpath(basePath))

	for path in sourcePaths:
		path = os.path.normpath(path)
		if os.path.isdir(path):
			zipRecurse(path, zipFile)
		else:
			zipFile.write(path)
	
	zipFile.close()
	return (1,)


# UNZIP

def unzip( destPath, zipFileName, overwrite = 0 ):
	zipFile = zipfile.ZipFile(os.path.normpath(zipFileName), "r", zipfile.ZIP_DEFLATED)
	destPath = os.path.normpath(destPath)
	destPath = os.path.normcase(destPath)
	sourcePath = ""

	filenames = zipFile.namelist()

	global zipInfoFilename
	for filename in filenames:
		if filename == zipInfoFilename:
			sourcePath = os.path.normcase(zipFile.read(zipInfoFilename))
			break

	# convert filenames into a list of pairs of zip file and actual file mappings
	filePairs = [];
	if sourcePath != "":
		for filename in filenames:
			filePairs.append((filename, string.replace(os.path.normcase(filename), sourcePath, destPath, 1)))
			#filePairs[len(a):] = [filename, string.replace(os.path.normcase(x), sourcePath, destPath, 1]
	else:
		for filename in filenames:
			filePairs.append((filename, filename))

	# check whether any of the files exist - either write all or none
	if not overwrite:
		for name in filePairs:
			if os.path.exists(name[1]):
				return (0,)
	
	for name in filePairs:
		if name[0] == zipInfoFilename:
			continue
		
		#print "extractingFile:", name[0], name[1]
		mkdirRecurse(os.path.dirname(name[1]))

		file = open(name[1], "wb") # make the file
		file.write(zipFile.read(name[0]))
		file.close()

	zipFile.close()
	return (1,)
